# Copyright (C) 2009, Olli Sikstus
# License: Creative Commons Attribution-Share Alike 3.0 Unported
# http://creativecommons.org/licenses/by-sa/3.0/

import pygame
import rabbyt

class RabbytGFX():
	def __init__(self, screenSize = (800, 600), fullScreen = False, title = ""):
		pygame.init()
		f = pygame.FULLSCREEN if fullScreen else 0
		self.screen = pygame.display.set_mode(screenSize, pygame.OPENGL|pygame.DOUBLEBUF|f)
		rabbyt.set_viewport(screenSize)
		rabbyt.set_default_attribs()

		self.offs = (-(screenSize[0] / 2), (screenSize[1] / 2))

		self.sprite = {}
		self.startTime = pygame.time.get_ticks()
		self.lastTime = self.startTime
		rabbyt.set_time(self.startTime / 1000.0)
		self.frames = 0
	
	def getTimeDelta(self):
		now = pygame.time.get_ticks()
		dT = now - self.lastTime
		self.lastTime = now
		return dT
	
	def clearTo(self, r, g, b):
		rabbyt.clear((r, g, b, 1.0))
	
	def beginFrame(self):
		rabbyt.clear()
	
	def endFrame(self):
		pygame.display.flip()
		self.frames += 1
	
	def getFps(self):
		return float(self.frames * 1000) / float(pygame.time.get_ticks() - self.startTime)
	
	def drawLine(self, color, startPos, endPos):
		pass
		
	def draw(self, image, x, y):
		sprite = self.getSprite(image)
		sprite.left = x + self.offs[0]
		sprite.top = -y + self.offs[1]
		sprite.render()
	
	def drawRot(self, image, deg, x, y):
		sprite = self.getSprite(image)
		sprite.left = x + self.offs[0]
		sprite.top = -y + self.offs[1]
		sprite.rot = deg
		sprite.render()
		sprite.rot = 0
	
	def drawAlpha(self, image, alpha, x, y):
		sprite = self.getSprite(image)
		sprite.left = x + self.offs[0]
		sprite.top = -y + self.offs[1]
		fAlpha = float(alpha) / 255.0
		sprite.alpha = fAlpha
		sprite.render()
		sprite.alpha = 1.0
	
	def getSprite(self, name):
		# Lazy image loading
		if name not in self.sprite:
			s = self.loadSprite(name)
			self.sprite[name] = s
		return self.sprite[name]
	
	def loadSprite(self, file):
		try:
			sprite = rabbyt.Sprite(file)
		except:
			print "Failed to load image: %s" % file
			raise SystemExit, "rabbyt.Sprite(file)"
		return sprite
